@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2013 The Kuali Foundation
+ * Copyright 2005-2014 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,6 +23,7 @@ import com.predic8.wsdl.Operation;
 import com.predic8.wsdl.PortType;
 import com.predic8.wsdl.WSDLParser;
 import com.predic8.wsdl.diff.WsdlDiffGenerator;
+import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.log4j.Logger;
 import org.codehaus.jackson.JsonNode;
@@ -81,7 +82,11 @@ public abstract class WsdlCompareTestCase extends BaselineTestCase {
 
     private static final List<String> ignoreBreakageRegexps = Arrays.asList(
             ".*Position of any changed from .*", // change in position of an 'any' doesn't indicate a breakage for us
-            ".*Position of element null changed.$" // this also indicates an 'any' changing position, ignore it too
+            ".*Position of element null changed.$", // this also indicates an 'any' changing position, ignore it too
+            " *ComplexType [^ ]* removed.$", // If a ComplexType that is unused is removed, it isn't a VC breakage
+
+            " *Element [^ ]* removed.$",   // If a simpleType that is unused is removed, it isn't a VC breakage, but
+            " *SimpleType [^ ]* removed.$" //   it produces both of these errors
     );
 
     public WsdlCompareTestCase(String moduleName) {
@@ -91,7 +96,7 @@ public abstract class WsdlCompareTestCase extends BaselineTestCase {
     protected List<String> verifyWsdlDifferences(Difference diff, String level) {
         List<String> results = new ArrayList<String>();
 
-        if (diff.isBreaks()) {
+        if (Boolean.TRUE.equals(diff.breaks())) {
             boolean ignore = false;
             for (String ignoreBreakageRegexp : ignoreBreakageRegexps) {
                 if (diff.getDescription().matches(ignoreBreakageRegexp)) {
@@ -101,20 +106,27 @@ public abstract class WsdlCompareTestCase extends BaselineTestCase {
             }
 
             if (ignore) {
-                LOG.info(level + "non-breaking change" + diff.getDescription());
+                LOG.info(level + "non-breaking change: " + diff.getDescription());
             } else {
                 LOG.error(level + "breaking change: " + diff.getType() + diff.getDescription());
                 results.add(level + diff.getDescription());
             }
+        } else {
+            LOG.trace(level + "trivial change: " + diff.getDescription());
         }
 
-
-        //check for operation based sequence changes
+        // check for operation based sequence changes
         String opBreakageString = checkForOperationBasedChanges(diff);
         if (opBreakageString != null) {
             results.add(level + opBreakageString);
         }
 
+        // check for previously empty responses changing to return something
+        String returnTypeBreakageString = checkForFormerlyVoidResponse(diff);
+        if (returnTypeBreakageString != null) {
+            results.add(level + returnTypeBreakageString);
+        }
+
         for (Difference moreDiff : diff.getDiffs())  {
             List<String> childBreakages = verifyWsdlDifferences(moreDiff, level + "  ");
             for (String childBreakage : childBreakages) {
@@ -142,10 +154,10 @@ public abstract class WsdlCompareTestCase extends BaselineTestCase {
      */
     private String checkForOperationBasedChanges(Difference diff) {
         if ("sequence".equals(diff.getType())
-                && diff.getA() != null
-                && diff.getB() != null) {
-            Sequence oldSequence = (Sequence)diff.getA();
-            Sequence newSequence = (Sequence)diff.getB();
+                && diff.getOriginal() != null
+                && diff.getModified() != null) {
+            Sequence oldSequence = (Sequence)diff.getOriginal();
+            Sequence newSequence = (Sequence)diff.getModified();
             if (newSequence.getParent() instanceof ComplexType) {
                 ComplexType parent = (ComplexType)newSequence.getParent();
                 String serviceName = newSequence.getSchema().getDefinitions().getName();
@@ -165,6 +177,46 @@ public abstract class WsdlCompareTestCase extends BaselineTestCase {
         return null;
     }
 
+    /**
+     * Check for previously void methods that now return something, which is a breaking change.
+     *
+     * <p>model-soa-core's WSDL differ does not recognize this as a breakage, so we have to detect this manually
+     * by looking at the model for return types and looking for previously empty sequences that change to have
+     * element(s) in them.</p>
+     *
+     * @param diff the diff to check for this type of breakage
+     * @return an error string if a VC breakage is found, or null if no breakage is detected.
+     */
+    private String checkForFormerlyVoidResponse(Difference diff) {
+        // Check for a sequence with a complextype parent whose name ends with response that went from empty to non-empty
+
+        if ( ! "sequence".equals(diff.getType()) || diff.getOriginal() == null || diff.getModified() == null) {
+            return null;
+        }
+
+        Sequence oldSequence = (Sequence)diff.getOriginal();
+        Sequence newSequence = (Sequence)diff.getModified();
+
+        if ( ! (newSequence.getParent() instanceof ComplexType)) {
+            return null;
+        }
+
+        ComplexType parent = (ComplexType)newSequence.getParent();
+
+        // Assumption: generated response types end with the name Response
+        if ( ! parent.getName().endsWith("Response")) {
+            return null;
+        }
+
+        // Check for a sequence with a complextype parent whose name ends with response that went from empty to non-empty
+        if (CollectionUtils.isEmpty(oldSequence.getElements()) &&
+                CollectionUtils.isNotEmpty(newSequence.getElements())) {
+            return "Element cannot be added to a previously empty return";
+        }
+
+        return null;
+    }
+
     protected List<Difference> compareWsdlDefinitions(String oldWsdl, String newWsdl) {
         WSDLParser parser = new WSDLParser();
 
@@ -265,7 +317,7 @@ public abstract class WsdlCompareTestCase extends BaselineTestCase {
         }
 
         if (!breakages.isEmpty()) {
-            fail("https://jira.kuali.org/browse/KULRICE-9849\n" + buildBreakagesSummary(breakages));
+            fail(buildBreakagesSummary(breakages));
         }
     }
 
