@@ -15,24 +15,12 @@
  */
 package org.kuali.rice.kns.web.struts.action;
 
-import java.io.IOException;
-
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpSession;
-
 import org.apache.commons.beanutils.PropertyUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.log4j.Logger;
 import org.apache.log4j.MDC;
 import org.apache.struts.Globals;
-import org.apache.struts.action.Action;
-import org.apache.struts.action.ActionForm;
-import org.apache.struts.action.ActionForward;
-import org.apache.struts.action.ActionMapping;
-import org.apache.struts.action.InvalidCancelException;
-import org.apache.struts.action.RequestProcessor;
+import org.apache.struts.action.*;
 import org.apache.struts.config.FormBeanConfig;
 import org.apache.struts.config.ForwardConfig;
 import org.apache.struts.util.RequestUtils;
@@ -43,12 +31,7 @@ import org.kuali.rice.core.api.util.RiceKeyConstants;
 import org.kuali.rice.kns.exception.FileUploadLimitExceededException;
 import org.kuali.rice.kns.service.KNSServiceLocator;
 import org.kuali.rice.kns.service.SessionDocumentService;
-import org.kuali.rice.kns.util.ErrorContainer;
-import org.kuali.rice.kns.util.InfoContainer;
-import org.kuali.rice.kns.util.KNSConstants;
-import org.kuali.rice.kns.util.KNSGlobalVariables;
-import org.kuali.rice.kns.util.WarningContainer;
-import org.kuali.rice.kns.util.WebUtils;
+import org.kuali.rice.kns.util.*;
 import org.kuali.rice.kns.web.EditablePropertiesHistoryHolder;
 import org.kuali.rice.kns.web.struts.form.KualiDocumentFormBase;
 import org.kuali.rice.kns.web.struts.form.KualiForm;
@@ -56,11 +39,9 @@ import org.kuali.rice.kns.web.struts.form.pojo.PojoForm;
 import org.kuali.rice.krad.UserSession;
 import org.kuali.rice.krad.document.Document;
 import org.kuali.rice.krad.exception.ValidationException;
-import org.kuali.rice.krad.util.GlobalVariables;
-import org.kuali.rice.krad.util.KRADConstants;
-import org.kuali.rice.krad.util.KRADUtils;
-import org.kuali.rice.krad.util.LegacyUtils;
-import org.kuali.rice.krad.util.MessageMap;
+import org.kuali.rice.krad.service.CsrfService;
+import org.kuali.rice.krad.service.KRADServiceLocatorWeb;
+import org.kuali.rice.krad.util.*;
 import org.springframework.dao.OptimisticLockingFailureException;
 import org.springframework.transaction.PlatformTransactionManager;
 import org.springframework.transaction.TransactionStatus;
@@ -68,6 +49,12 @@ import org.springframework.transaction.support.TransactionCallback;
 import org.springframework.transaction.support.TransactionTemplate;
 import org.springmodules.orm.ojb.OjbOperationException;
 
+import javax.servlet.ServletException;
+import javax.servlet.http.HttpServletRequest;
+import javax.servlet.http.HttpServletResponse;
+import javax.servlet.http.HttpSession;
+import java.io.IOException;
+
 /**
  * This class handles setup of user session and restoring of action form.
  * 
@@ -83,6 +70,7 @@ public class KualiRequestProcessor extends RequestProcessor {
 
 	private SessionDocumentService sessionDocumentService;
 	private PlatformTransactionManager transactionManager;
+	private CsrfService csrfService;
 
     @Override
     public void process(final HttpServletRequest request,
@@ -225,6 +213,12 @@ public class KualiRequestProcessor extends RequestProcessor {
     	ActionForm form = processActionForm(request, response, mapping);
         processPopulate(request, response, form, mapping);
 
+        // need to make sure that we don't check CSRF until after the form is populated so that Struts will parse the
+        // multipart parameters into the request if it's a multipart request
+        if (!getCsrfService().validateCsrfIfNecessary(request, response)) {
+            return;
+        }
+
         // Create or acquire the Action instance to process this request
 		Action action = processActionCreate(request, response, mapping);
 
@@ -243,7 +237,6 @@ public class KualiRequestProcessor extends RequestProcessor {
         }
     }
 
-
 	/**
 	 * This method gets the document number from the request.  The request should have been processed already 
 	 * before this is called if it is multipart.  
@@ -388,7 +381,6 @@ public class KualiRequestProcessor extends RequestProcessor {
 		String docFormKey = request.getParameter(KRADConstants.DOC_FORM_KEY);
 		String methodToCall = request.getParameter(KRADConstants.DISPATCH_REQUEST_PARAMETER);
 		String refreshCaller = request.getParameter(KRADConstants.REFRESH_CALLER);
-//		String searchListRequestKey = request.getParameter(KRADConstants.SEARCH_LIST_REQUEST_KEY);
 		String documentWebScope = request.getParameter(KRADConstants.DOCUMENT_WEB_SCOPE);
 
 		if (mapping.getPath().startsWith(KRADConstants.REFRESH_MAPPING_PREFIX) || KRADConstants.RETURN_METHOD_TO_CALL.equalsIgnoreCase(methodToCall) ||
@@ -762,6 +754,13 @@ public class KualiRequestProcessor extends RequestProcessor {
 		}
 		return this.transactionManager;
 	}
+
+	public CsrfService getCsrfService() {
+		if (csrfService == null) {
+			csrfService = KRADServiceLocatorWeb.getCsrfService();
+		}
+		return csrfService;
+	}
 	
 	private ActionForm createNewActionForm(ActionMapping mapping, HttpServletRequest request) {
         String name = mapping.getName();
@@ -779,4 +778,5 @@ public class KualiRequestProcessor extends RequestProcessor {
         }
         return instance;
 	}
+
 }
