@@ -497,8 +497,8 @@ function coerceValue(name) {
     // when group is opened in lightbox make sure to get the value from field in the lightbox
     // if that field is in the lightbox
     var parent = document;
-    if (jQuery(nameSelect, jQuery(".fancybox-wrap")).length) {
-        parent = jQuery(".fancybox-wrap");
+    if (jQuery(nameSelect, jQuery("#fancybox-wrap")).length) {
+        parent = jQuery("#fancybox-wrap");
     }
 
     if (jQuery(nameSelect + ":checkbox", parent).length == 1) {
@@ -1054,7 +1054,7 @@ function _showLightboxComponentHelper(componentId, overrideOptions) {
         // ensure that component of KualiForm gets updated after fancybox closes
         _appendCallbackFunctions(overrideOptions, {beforeClose: function () {
             // hack fancybox to prevent it from moving the original lightbox content into the body
-            jQuery('#' + componentId).parents('.fancybox-wrap').unbind('onReset');
+            jQuery('#' + componentId).parents('#fancybox-wrap').unbind('onReset');
 
             jQuery('#tmpForm_' + componentId).replaceWith(jQuery('#' + componentId).detach());
             jQuery('#' + componentId).css('display', cssDisplay);
@@ -1066,7 +1066,7 @@ function _showLightboxComponentHelper(componentId, overrideOptions) {
         // reattach component to KualiForm after fancybox closes
         _appendCallbackFunctions(overrideOptions, {beforeClose: function () {
             // hack fancybox to prevent it from moving the original lightbox content into the body
-            parent.jQuery('#' + componentId).parents('.fancybox-wrap').unbind('onReset');
+            parent.jQuery('#' + componentId).parents('#fancybox-wrap').unbind('onReset');
 
             jQuery('#tmpForm_' + componentId).replaceWith(parent.jQuery('#' + componentId).detach());
             jQuery('#' + componentId).css('display', cssDisplay);
@@ -1139,14 +1139,13 @@ function showLightboxUrl(url, overrideOptions) {
  * @param overrideOptions the map of option settings (option name/value pairs) for the plugin. This is optional.
  */
 function _initAndOpenLightbox(contentOptions, overrideOptions) {
-    var options = {fitToView: true,
-        openEffect: 'fade',
-        closeEffect: 'fade',
-        openSpeed: 200,
-        closeSpeed: 200,
-        minHeight: 10,
-        //minWidth: 10,
-        helpers: {overlay: {css: {cursor: 'arrow'}, closeClick: false}}
+    var options = { autoScale: true,
+        transitionIn: 'fade',
+        transitionOut: 'fade',
+        speedIn: 200,
+        speedOut: 200,
+        hideOnContentClick: false,
+        padding: 0
     };
 
     // override fancybox content options
@@ -1166,7 +1165,7 @@ function _initAndOpenLightbox(contentOptions, overrideOptions) {
  *  Wrap the div to display in the light box in a form and setup form for validation and dirty checks
  */
 function setupLightboxForm() {
-    jQuery(".fancybox-inner").children().wrap("<form id='kualiLightboxForm' class='uif-lightbox'>");
+    jQuery("#fancybox-content").children().wrap("<form id='kualiLightboxForm' class='uif-lightbox'>");
 
     var kualiLightboxForm = jQuery('#kualiLightboxForm');
     setupValidator(kualiLightboxForm);
