@@ -15,34 +15,40 @@
  */
 package org.kuali.rice.krad.uif.element;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
-import org.apache.commons.lang.StringUtils;
-import org.kuali.rice.krad.datadictionary.parse.BeanTag;
-import org.kuali.rice.krad.datadictionary.parse.BeanTagAttribute;
-import org.kuali.rice.krad.uif.UifConstants;
-import org.kuali.rice.krad.uif.component.Component;
-import org.kuali.rice.krad.uif.container.Container;
-import org.kuali.rice.krad.uif.container.ContainerBase;
-import org.kuali.rice.krad.uif.container.PageGroup;
-import org.kuali.rice.krad.uif.field.FieldGroup;
-import org.kuali.rice.krad.uif.field.InputField;
-import org.kuali.rice.krad.uif.util.MessageStructureUtils;
-import org.kuali.rice.krad.uif.view.View;
-import org.kuali.rice.krad.util.ErrorMessage;
-import org.kuali.rice.krad.util.GlobalVariables;
-import org.kuali.rice.krad.util.KRADUtils;
-import org.kuali.rice.krad.util.MessageMap;
-import org.springframework.util.AutoPopulatingList;
-
-import java.beans.PropertyEditor;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.HashSet;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
+import java.util.Queue;
+
+import org.apache.commons.lang.StringUtils;
+import org.kuali.rice.krad.datadictionary.parse.BeanTag;
+import org.kuali.rice.krad.datadictionary.parse.BeanTagAttribute;
+import org.kuali.rice.krad.datadictionary.uif.UifDictionaryBeanBase;
+import org.kuali.rice.krad.messages.MessageService;
+import org.kuali.rice.krad.service.KRADServiceLocatorWeb;
+import org.kuali.rice.krad.uif.UifConstants;
+import org.kuali.rice.krad.uif.component.Component;
+import org.kuali.rice.krad.uif.component.DataBinding;
+import org.kuali.rice.krad.uif.container.Container;
+import org.kuali.rice.krad.uif.container.ContainerBase;
+import org.kuali.rice.krad.uif.field.FieldGroup;
+import org.kuali.rice.krad.uif.field.InputField;
+import org.kuali.rice.krad.uif.lifecycle.ViewLifecycleUtils;
+import org.kuali.rice.krad.uif.util.LifecycleElement;
+import org.kuali.rice.krad.uif.util.MessageStructureUtils;
+import org.kuali.rice.krad.uif.util.RecycleUtils;
+import org.kuali.rice.krad.uif.view.View;
+import org.kuali.rice.krad.util.AuditCluster;
+import org.kuali.rice.krad.util.AuditError;
+import org.kuali.rice.krad.util.ErrorMessage;
+import org.kuali.rice.krad.util.GlobalVariables;
+import org.kuali.rice.krad.util.KRADConstants;
+import org.kuali.rice.krad.util.KRADUtils;
+import org.kuali.rice.krad.util.MessageMap;
 
 /**
  * Field that displays error, warning, and info messages for the keys that are
@@ -57,8 +63,8 @@ import java.util.Set;
  *
  * @author Kuali Rice Team (rice.collab@kuali.org)
  */
-@BeanTag(name = "validationMessages-bean", parent = "Uif-ValidationMessagesBase")
-public class ValidationMessages extends ContentElementBase {
+@BeanTag(name = "validationMessages", parent = "Uif-ValidationMessagesBase")
+public class ValidationMessages extends UifDictionaryBeanBase {
     private static final long serialVersionUID = 780940788435330077L;
 
     private List<String> additionalKeysToMatch;
@@ -70,39 +76,17 @@ public class ValidationMessages extends ContentElementBase {
     private List<String> warnings;
     private List<String> infos;
 
-    private Map<String, String> validationDataDefaults;
-
-    /**
-     * PerformFinalize will generate the messages and counts used by the
-     * errorsField based on the keys that were matched from the MessageMap for
-     * this ValidationMessages. It will also set up nestedComponents of its
-     * parentComponent correctly based on the flags that were chosen for this
-     * ValidationMessages.
-     *
-     * @see org.kuali.rice.krad.uif.field.FieldBase#performFinalize(org.kuali.rice.krad.uif.view.View,
-     *      java.lang.Object, org.kuali.rice.krad.uif.component.Component)
-     */
-    @Override
-    public void performFinalize(View view, Object model, Component parent) {
-        super.performFinalize(view, model, parent);
-
-        generateMessages(true, view, model, parent);
-    }
-
     /**
      * Generates the messages based on the content in the messageMap
      *
-     * @param reset true to reset the errors, warnings, and info lists
      * @param view the current View
      * @param model the current model
      * @param parent the parent of this ValidationMessages
      */
-    public void generateMessages(boolean reset, View view, Object model, Component parent) {
-        if (reset) {
-            errors = new ArrayList<String>();
-            warnings = new ArrayList<String>();
-            infos = new ArrayList<String>();
-        }
+    public void generateMessages(View view, Object model, Component parent) {
+        errors = new ArrayList<String>();
+        warnings = new ArrayList<String>();
+        infos = new ArrayList<String>();
 
         List<String> masterKeyList = getKeys(parent);
         MessageMap messageMap = GlobalVariables.getMessageMap();
@@ -120,22 +104,21 @@ public class ValidationMessages extends ContentElementBase {
 
         // special message component case
         if (parentContainer != null && parentContainer instanceof Message && ((Message) parentContainer)
-                .isGenerateSpan()) {
+                .isRenderWrapperTag()) {
             parentContainerId = ((Component) parentContainer).getId();
         }
 
         // special case for nested contentElement with no parent
         if (parentContainer != null && parentContainer instanceof Component && StringUtils.isBlank(parentContainerId)) {
-            parentContainer = ((Component) parentContainer).getContext().get("parent");
+            parentContext = ((Component) parentContainer).getContext();
+            parentContainer = parentContext == null ? null : parentContext
+                    .get(UifConstants.ContextVariableNames.PARENT);
             if (parentContainer != null && (parentContainer instanceof Container
                     || parentContainer instanceof FieldGroup)) {
                 parentContainerId = ((Component) parentContainer).getId();
             }
         }
 
-        //Add identifying data attributes
-        this.addDataAttribute(UifConstants.DataAttributes.MESSAGES_FOR, parent.getId());
-
         if ((parent.getDataAttributes() == null) || (parent.getDataAttributes().get(UifConstants.DataAttributes.PARENT)
                 == null)) {
             parent.addDataAttribute(UifConstants.DataAttributes.PARENT, parentContainerId);
@@ -147,31 +130,7 @@ public class ValidationMessages extends ContentElementBase {
             masterKeyList.add(parentContainerId);
         }
 
-        //Check for message keys that are not matched anywhere on the page - these unmatched messages must still be
-        //displayed at the page level
-        if (parent instanceof PageGroup) {
-            Map<String, PropertyEditor> propertyEditors = view.getViewIndex().getFieldPropertyEditors();
-            Map<String, PropertyEditor> securePropertyEditors = view.getViewIndex().getSecureFieldPropertyEditors();
-            List<String> allPossibleKeys = new ArrayList<String>(propertyEditors.keySet());
-            allPossibleKeys.addAll(securePropertyEditors.keySet());
-
-            this.addNestedGroupKeys(allPossibleKeys, parent);
-            if (additionalKeysToMatch != null) {
-                allPossibleKeys.addAll(additionalKeysToMatch);
-            }
-            if (StringUtils.isNotBlank(parent.getId())) {
-                allPossibleKeys.add(parent.getId());
-            }
-
-            Set<String> messageKeys = new HashSet<String>();
-            messageKeys.addAll(messageMap.getAllPropertiesWithErrors());
-            messageKeys.addAll(messageMap.getAllPropertiesWithWarnings());
-            messageKeys.addAll(messageMap.getAllPropertiesWithInfo());
-
-            messageKeys.removeAll(allPossibleKeys);
-
-            masterKeyList.addAll(messageKeys);
-        }
+        processAuditErrors(masterKeyList);
 
         for (String key : masterKeyList) {
             errors.addAll(getMessages(view, key, messageMap.getErrorMessagesForProperty(key, true)));
@@ -180,6 +139,53 @@ public class ValidationMessages extends ContentElementBase {
         }
     }
 
+    /**
+     * Process any AuditErrors which exist in AuditClusters in the AuditErrorMap of GlobalVariables and add them
+     * to either errors or warnings for this component, matching on errorKey.
+     *
+     * @param masterKeyList the keys to look for
+     */
+    private void processAuditErrors(List<String> masterKeyList) {
+        Map<String, AuditCluster> clusterMap = GlobalVariables.getAuditErrorMap();
+
+        for (AuditCluster auditCluster : clusterMap.values()) {
+            boolean isError = !(auditCluster.getCategory().equals(KRADConstants.Audit.AUDIT_WARNINGS));
+
+            List<AuditError> auditErrors = auditCluster.getAuditErrorList();
+            if (auditErrors == null) {
+                continue;
+            }
+
+            for (AuditError auditError: auditErrors) {
+                if (!masterKeyList.contains(auditError.getValidationKey())) {
+                    continue;
+                }
+
+                MessageService messageService = KRADServiceLocatorWeb.getMessageService();
+
+                // find message by key
+                String message = messageService.getMessageText(auditError.getMessageKey());
+                if (message == null) {
+                    message = "Intended message with key: " + auditError.getErrorKey() + " not found.";
+                }
+
+                if (auditError.getParams() != null && StringUtils.isNotBlank(message)) {
+                    message = message.replace("'", "''");
+                    message = MessageFormat.format(message, auditError.getParams());
+                }
+
+                message = MessageStructureUtils.translateStringMessage(message);
+
+                if (isError) {
+                    errors.add(message);
+                }
+                else {
+                    warnings.add(message);
+                }
+            }
+        }
+    }
+
     /**
      * Gets all the messages from the list of lists passed in (which are
      * lists of ErrorMessages associated to the key) and uses the configuration
@@ -191,9 +197,9 @@ public class ValidationMessages extends ContentElementBase {
      * @param view
      * @param key
      * @param lists
-     * @return
+     * @return list of messages
      */
-    private List<String> getMessages(View view, String key, List<AutoPopulatingList<ErrorMessage>> lists) {
+    protected List<String> getMessages(View view, String key, List<List<ErrorMessage>> lists) {
         List<String> result = new ArrayList<String>();
         for (List<ErrorMessage> errorList : lists) {
             if (errorList != null && StringUtils.isNotBlank(key)) {
@@ -212,24 +218,27 @@ public class ValidationMessages extends ContentElementBase {
     /**
      * Gets all the keys associated to this ValidationMessages. This includes the id of
      * the parent component, additional keys to match, and the bindingPath if
-     * this is an ValidationMessages for an InputField. These are the keys that are
+     * this is a ValidationMessages for a DataBinding component. These are the keys that are
      * used to match errors with their component and display them as part of its
      * ValidationMessages.
      *
-     * @return
+     * @return list of keys
      */
     protected List<String> getKeys(Component parent) {
         List<String> keyList = new ArrayList<String>();
+
         if (additionalKeysToMatch != null) {
             keyList.addAll(additionalKeysToMatch);
         }
+
         if (StringUtils.isNotBlank(parent.getId())) {
             keyList.add(parent.getId());
         }
-        if (parent instanceof InputField) {
-            if (((InputField) parent).getBindingInfo() != null && StringUtils.isNotEmpty(
-                    ((InputField) parent).getBindingInfo().getBindingPath())) {
-                keyList.add(((InputField) parent).getBindingInfo().getBindingPath());
+
+        if (parent instanceof DataBinding) {
+            if (((DataBinding) parent).getBindingInfo() != null && StringUtils.isNotEmpty(
+                    ((DataBinding) parent).getBindingInfo().getBindingPath())) {
+                keyList.add(((DataBinding) parent).getBindingInfo().getBindingPath());
             }
         }
 
@@ -243,18 +252,30 @@ public class ValidationMessages extends ContentElementBase {
      * @param keyList
      * @param component
      */
-    private void addNestedGroupKeys(Collection<String> keyList, Component component) {
-        for (Component c : component.getComponentsForLifecycle()) {
-            ValidationMessages ef = null;
-            if (c instanceof ContainerBase) {
-                ef = ((ContainerBase) c).getValidationMessages();
-            } else if (c instanceof FieldGroup) {
-                ef = ((FieldGroup) c).getGroup().getValidationMessages();
-            }
-            if (ef != null) {
-                keyList.addAll(ef.getKeys(c));
-                addNestedGroupKeys(keyList, c);
+    protected void addNestedGroupKeys(Collection<String> keyList, Component component) {
+        @SuppressWarnings("unchecked")
+        Queue<LifecycleElement> elementQueue = RecycleUtils.getInstance(LinkedList.class);
+        try {
+            elementQueue.addAll(ViewLifecycleUtils.getElementsForLifecycle(component).values());
+            while (!elementQueue.isEmpty()) {
+                LifecycleElement element = elementQueue.poll();
+
+                ValidationMessages ef = null;
+                if (element instanceof ContainerBase) {
+                    ef = ((ContainerBase) element).getValidationMessages();
+                } else if (element instanceof FieldGroup) {
+                    ef = ((FieldGroup) element).getGroup().getValidationMessages();
+                }
+                
+                if (ef != null) {
+                    keyList.addAll(ef.getKeys((Component) element));
+                }
+
+                elementQueue.addAll(ViewLifecycleUtils.getElementsForLifecycle(element).values());
             }
+        } finally {
+            elementQueue.clear();
+            RecycleUtils.recycle(elementQueue);
         }
     }
 
@@ -266,7 +287,7 @@ public class ValidationMessages extends ContentElementBase {
      *
      * @return the additionalKeysToMatch
      */
-    @BeanTagAttribute(name = "additionalKeysToMatch", type = BeanTagAttribute.AttributeType.LISTVALUE)
+    @BeanTagAttribute
     public List<String> getAdditionalKeysToMatch() {
         return this.additionalKeysToMatch;
     }
@@ -303,7 +324,7 @@ public class ValidationMessages extends ContentElementBase {
      *
      * @return the displayMessages
      */
-    @BeanTagAttribute(name = "displayMessages")
+    @BeanTagAttribute
     public boolean isDisplayMessages() {
         return this.displayMessages;
     }
@@ -321,41 +342,64 @@ public class ValidationMessages extends ContentElementBase {
      *
      * @return the errors
      */
-    @BeanTagAttribute(name = "errors", type = BeanTagAttribute.AttributeType.LISTVALUE)
+    @BeanTagAttribute
     public List<String> getErrors() {
         return this.errors;
     }
 
+    /**
+     * @see ValidationMessages#getErrors()
+     */
+    protected void setErrors(List<String> errors) {
+        this.errors = errors;
+    }
+
     /**
      * The list of warning messages found for the keys that were matched on this
      * ValidationMessages This is generated and cannot be set
      *
      * @return the warnings
      */
-    @BeanTagAttribute(name = "warnings", type = BeanTagAttribute.AttributeType.LISTVALUE)
+    @BeanTagAttribute
     public List<String> getWarnings() {
         return this.warnings;
     }
 
+    /**
+     * @see ValidationMessages#getWarnings()
+     */
+    protected void setWarnings(List<String> warnings) {
+        this.warnings = warnings;
+    }
+
     /**
      * The list of info messages found for the keys that were matched on this
      * ValidationMessages This is generated and cannot be set
      *
      * @return the infos
      */
-    @BeanTagAttribute(name = "infos", type = BeanTagAttribute.AttributeType.LISTVALUE)
+    @BeanTagAttribute
     public List<String> getInfos() {
         return this.infos;
     }
 
-    public Map<String, String> getValidationDataDefaults() {
-        return validationDataDefaults;
-    }
-
-    public void setValidationDataDefaults(Map<String, String> validationDataDefaults) {
-        this.validationDataDefaults = validationDataDefaults;
+    /**
+     * @see ValidationMessages#getInfos()
+     */
+    protected void setInfos(List<String> infos) {
+        this.infos = infos;
     }
 
+    /**
+     * Adds the value passed to the valueMap with the key specified, if the value does not match the
+     * value which already exists in defaults (to avoid having to write out extra data that can later
+     * be derived from the defaults in the js)
+     *
+     * @param valueMap the data map being constructed
+     * @param defaults defaults for validation messages
+     * @param key the variable name being added
+     * @param value the value set on this object
+     */
     protected void addValidationDataSettingsValue(Map<String, Object> valueMap, Map<String, String> defaults,
             String key, Object value) {
         String defaultValue = defaults.get(key);
@@ -365,90 +409,4 @@ public class ValidationMessages extends ContentElementBase {
         }
     }
 
-    /**
-     * Sets errors
-     *
-     * @param errors
-     */
-    protected void setErrors(List<String> errors) {
-        this.errors = errors;
-    }
-
-    /**
-     * Sets warnings
-     *
-     * @param warnings
-     */
-    protected void setWarnings(List<String> warnings) {
-        this.warnings = warnings;
-    }
-
-    /**
-     * Sets infos
-     *
-     * @param infos
-     */
-    protected void setInfos(List<String> infos) {
-        this.infos = infos;
-    }
-
-    /**
-     * @see org.kuali.rice.krad.uif.component.ComponentBase#copy()
-     */
-    @Override
-    protected <T> void copyProperties(T component) {
-        super.copyProperties(component);
-        ValidationMessages validationMessagesCopy = (ValidationMessages) component;
-
-        if (additionalKeysToMatch != null) {
-            List<String> additionalKeysToMatchCopy = Lists.newArrayListWithExpectedSize(additionalKeysToMatch.size());
-            for (String additionalKeyToMatch : additionalKeysToMatch) {
-                additionalKeysToMatchCopy.add(additionalKeyToMatch);
-            }
-
-            validationMessagesCopy.setAdditionalKeysToMatch(additionalKeysToMatchCopy);
-        }
-
-        validationMessagesCopy.setDisplayMessages(this.displayMessages);
-
-        if (warnings != null) {
-            // Error messages
-            List<String> warningsCopy = Lists.newArrayListWithExpectedSize(warnings.size());
-            for (String warning : warnings) {
-                warningsCopy.add(warning);
-            }
-
-            validationMessagesCopy.setWarnings(warningsCopy);
-        }
-
-        if (errors != null) {
-            List<String> errorsCopy = Lists.newArrayListWithExpectedSize(errors.size());
-            for (String error : errors) {
-                errorsCopy.add(error);
-            }
-
-            validationMessagesCopy.setErrors(errorsCopy);
-        }
-
-        if (infos != null) {
-            List<String> infosCopy = Lists.newArrayListWithExpectedSize(infos.size());
-            for (String info : infos) {
-                infosCopy.add(info);
-            }
-
-            validationMessagesCopy.setInfos(infosCopy);
-        }
-
-        if (this.validationDataDefaults != null) {
-            Map<String, String> validationDataDefaultsCopy = Maps.newHashMapWithExpectedSize(
-                    this.validationDataDefaults.size());
-            for (Map.Entry validationDataDefault : validationDataDefaults.entrySet()) {
-                validationDataDefaultsCopy.put(validationDataDefault.getKey().toString(),
-                        validationDataDefault.getValue().toString());
-            }
-
-            validationMessagesCopy.setValidationDataDefaults(validationDataDefaultsCopy);
-        }
-    }
-
 }
